@@ -1,6 +1,8 @@
 export LANG=C
+export PATH=/opt/pgsql/bin:$PATH
 cd /opt/pgsql/share/contrib/postgis-1.5
-dbname=template1
+dbname=postgis
+    createdb $dbname
     createlang plpgsql $dbname
     psql -f postgis.sql -d $dbname
     psql -f spatial_ref_sys.sql -d $dbname
